@@ -19,7 +19,7 @@ try:
     import re
 except:
     pikepdf = None
-    from PyPDF2 import PdfFileWriter, PdfFileReader
+    from PyPDF2 import PdfFileWriter, PdfFileReader, generic
     from copy import copy
 
 from decimal import Decimal
@@ -35,7 +35,9 @@ def _mediabox(row, angle, angle0, box):
             for it in range(rotate_times):
                 perm.append(perm.pop(0))
             perm.insert(1, perm.pop(2))
-            crop = [Decimal(crop_init[perm[side]]) for side in range(4)]
+            crop = [crop_init[perm[side]] for side in range(4)]
+        # PyPDF2 FloatObject instances are decimal.Decimal objects
+        crop = [Decimal(x) for x in crop]
         x1, y1, x2, y2 = box
         x1_new = x1 + (x2 - x1) * crop[0]
         x2_new = x2 - (x2 - x1) * crop[1]
@@ -95,7 +97,9 @@ def _pypdf2(input_files, pages, file_out):
         # Workaround for https://github.com/mstamy2/PyPDF2/issues/337
         angle0 = angle0 if isinstance(angle0, int) else angle0.getObject()
         if angle != 0:
-            current_page.rotateClockwise(angle)
+            # rotateClockwise does not work if current angle is an IndirectObject
+            a = generic.NumberObject(angle0 + angle)
+            current_page[generic.NameObject("/Rotate")] = a
 
         cropped = _mediabox(row, angle, angle0, list(current_page.mediaBox.lowerLeft) +
                             list(current_page.mediaBox.upperRight))
